[Vm-dev] [commit][3721] CogVM source as per VMMaker.oscog-eem.1860

commits at squeakvm.org commits at squeakvm.org
Tue May 17 07:02:35 UTC 2016


Revision: 3721
Author:   eliot
Date:     2016-05-17 00:02:33 -0700 (Tue, 17 May 2016)
Log Message:
-----------
CogVM source as per VMMaker.oscog-eem.1860

Fix assert in primitiveVoidVMStateForMethod; ensureFrameIsMarried:SP: expects the stack
pointer to exclude/point above any instruction pointer.

Include the VM plugins in the squeak.stack.spur mac build while debugging the ARM sim.

Modified Paths:
--------------
    branches/Cog/build.macos32x86/squeak.stack.spur/plugins.ext
    branches/Cog/nsspur64src/vm/cogit.h
    branches/Cog/nsspur64src/vm/cogitX64.c
    branches/Cog/nsspur64src/vm/cointerp.c
    branches/Cog/nsspur64src/vm/cointerp.h
    branches/Cog/nsspur64src/vm/gcc3x-cointerp.c
    branches/Cog/nsspursrc/vm/cogit.h
    branches/Cog/nsspursrc/vm/cogitARMv5.c
    branches/Cog/nsspursrc/vm/cogitIA32.c
    branches/Cog/nsspursrc/vm/cogitMIPSEL.c
    branches/Cog/nsspursrc/vm/cointerp.c
    branches/Cog/nsspursrc/vm/cointerp.h
    branches/Cog/nsspursrc/vm/gcc3x-cointerp.c
    branches/Cog/nsspurstack64src/vm/gcc3x-interp.c
    branches/Cog/nsspurstack64src/vm/interp.c
    branches/Cog/nsspurstacksrc/vm/gcc3x-interp.c
    branches/Cog/nsspurstacksrc/vm/interp.c
    branches/Cog/spur64src/vm/cogit.h
    branches/Cog/spur64src/vm/cogitX64.c
    branches/Cog/spur64src/vm/cointerp.c
    branches/Cog/spur64src/vm/cointerp.h
    branches/Cog/spur64src/vm/gcc3x-cointerp.c
    branches/Cog/spursistasrc/vm/cogit.h
    branches/Cog/spursistasrc/vm/cogitARMv5.c
    branches/Cog/spursistasrc/vm/cogitIA32.c
    branches/Cog/spursistasrc/vm/cogitMIPSEL.c
    branches/Cog/spursistasrc/vm/cointerp.c
    branches/Cog/spursistasrc/vm/cointerp.h
    branches/Cog/spursistasrc/vm/gcc3x-cointerp.c
    branches/Cog/spursrc/vm/cogit.h
    branches/Cog/spursrc/vm/cogitARMv5.c
    branches/Cog/spursrc/vm/cogitIA32.c
    branches/Cog/spursrc/vm/cogitMIPSEL.c
    branches/Cog/spursrc/vm/cointerp.c
    branches/Cog/spursrc/vm/cointerp.h
    branches/Cog/spursrc/vm/gcc3x-cointerp.c
    branches/Cog/spurstack64src/vm/gcc3x-interp.c
    branches/Cog/spurstack64src/vm/interp.c
    branches/Cog/spurstacksrc/vm/gcc3x-interp.c
    branches/Cog/spurstacksrc/vm/interp.c
    branches/Cog/src/vm/cogit.h
    branches/Cog/src/vm/cogitARMv5.c
    branches/Cog/src/vm/cogitIA32.c
    branches/Cog/src/vm/cogitMIPSEL.c
    branches/Cog/src/vm/cointerp.c
    branches/Cog/src/vm/cointerp.h
    branches/Cog/src/vm/cointerpmt.c
    branches/Cog/src/vm/cointerpmt.h
    branches/Cog/src/vm/gcc3x-cointerp.c
    branches/Cog/src/vm/gcc3x-cointerpmt.c
    branches/Cog/stacksrc/vm/gcc3x-interp.c
    branches/Cog/stacksrc/vm/interp.c

Property Changed:
----------------
    branches/Cog/platforms/Cross/vm/sqSCCSVersion.h

Modified: branches/Cog/build.macos32x86/squeak.stack.spur/plugins.ext
===================================================================
--- branches/Cog/build.macos32x86/squeak.stack.spur/plugins.ext	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/build.macos32x86/squeak.stack.spur/plugins.ext	2016-05-17 07:02:33 UTC (rev 3721)
@@ -1,6 +1,9 @@
 # Copied, perhaps edited, from ../src/examplePlugins.ext
 # MIDIPlugin does not work on Cocoa so keep it external until it can be fixed.
 EXTERNAL_PLUGINS = \
+BochsIA32Plugin \
+BochsX64Plugin \
+GdbARMPlugin \
 CroquetPlugin \
 MIDIPlugin \
 Mpeg3Plugin \

Modified: branches/Cog/nsspur64src/vm/cogit.h
===================================================================
--- branches/Cog/nsspur64src/vm/cogit.h	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/nsspur64src/vm/cogit.h	2016-05-17 07:02:33 UTC (rev 3721)
@@ -1,5 +1,5 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGenerator VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
 
 

Modified: branches/Cog/nsspur64src/vm/cogitX64.c
===================================================================
--- branches/Cog/nsspur64src/vm/cogitX64.c	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/nsspur64src/vm/cogitX64.c	2016-05-17 07:02:33 UTC (rev 3721)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGenerator VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
    from
-	StackToRegisterMappingCogit VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	StackToRegisterMappingCogit VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
-static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34 " __DATE__ ;
+static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -2796,7 +2796,7 @@
     sqInt byte;
     BytecodeDescriptor *descriptor;
     sqInt distance;
-    sqInt endbcpc;
+    usqInt endbcpc;
     CogMethod *homeMethod;
     sqInt isBackwardBranch;
     sqInt isInBlock;
@@ -3667,7 +3667,7 @@
 closedPICRefersToUnmarkedObject(CogMethod *cPIC)
 {
     sqInt i;
-    usqInt object;
+    sqInt object;
     sqInt pc;
 
 	if (!((isImmediate((cPIC->selector)))
@@ -5236,9 +5236,9 @@
 findMapLocationForMcpcinMethod(sqInt targetMcpc, CogMethod *cogMethod)
 {
     sqInt annotation;
-    sqInt map;
+    usqInt map;
     sqInt mapByte;
-    sqInt mcpc;
+    usqInt mcpc;
 
 	mcpc = (0
 		? (((usqInt)cogMethod)) + cbNoSwitchEntryOffset
@@ -5914,12 +5914,12 @@
 generateMapAtstart(sqInt addressOrNull, sqInt startAddress)
 {
     unsigned char annotation;
-    sqInt delta;
+    usqInt delta;
     sqInt i;
     AbstractInstruction *instruction;
     sqInt length;
-    sqInt location;
-    sqInt mapEntry;
+    usqInt location;
+    usqInt mapEntry;
     sqInt maxDelta;
     usqInt mcpc;
 
@@ -8198,7 +8198,7 @@
     sqInt byte;
     BytecodeDescriptor *descriptor;
     sqInt distance;
-    sqInt endbcpc;
+    usqInt endbcpc;
     CogMethod *homeMethod;
     sqInt isBackwardBranch;
     sqInt isInBlock;
@@ -8641,9 +8641,9 @@
 printPCMapPairsFor(CogMethod *cogMethod)
 {
     sqInt annotation;
-    sqInt map;
+    usqInt map;
     unsigned char mapByte;
-    sqInt mcpc;
+    usqInt mcpc;
     sqInt value;
 
 	mcpc = (0
@@ -23144,7 +23144,7 @@
     CogBlockMethod *cogMethod1;
     BytecodeDescriptor *descriptor;
     sqInt distance;
-    sqInt endbcpc;
+    usqInt endbcpc;
     sqInt errCode;
     CogMethod *homeMethod;
     sqInt isBackwardBranch;

Modified: branches/Cog/nsspur64src/vm/cointerp.c
===================================================================
--- branches/Cog/nsspur64src/vm/cointerp.c	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/nsspur64src/vm/cointerp.c	2016-05-17 07:02:33 UTC (rev 3721)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
    from
-	CoInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CoInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
-static char __buildInfo[] = "CoInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34 " __DATE__ ;
+static char __buildInfo[] = "CoInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24 " __DATE__ ;
 char *__interpBuildInfo = __buildInfo;
 
 
@@ -2436,7 +2436,7 @@
 /*560*/	-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1, 0, 0, 0,-1,-1
 	};
 char expensiveAsserts = 0;
-const char *interpreterVersion = "Newspeak Virtual Machine CoInterpreterPrimitives_VMMaker.oscog-eem.1856";
+const char *interpreterVersion = "Newspeak Virtual Machine CoInterpreterPrimitives_VMMaker.oscog-eem.1860";
 sqInt minBackwardJumpCountForCompile = MinBackwardJumpCountForCompile /* 40 */;
 volatile int sendTrace;
 
@@ -17754,7 +17754,7 @@
 static sqInt
 checkForAndFollowForwardedPrimitiveState(void)
 {   DECL_MAYBE_SQ_GLOBAL_STRUCT
-    signed char accessorDepth;
+    sqInt accessorDepth;
     sqInt firstBytecode;
     sqInt found;
     sqInt found1;
@@ -28128,7 +28128,7 @@
 	(GIV(stackPage)->headSP = GIV(stackPointer));
 	assert(pageListIsWellFormed());
 	/* begin ensureFrameIsMarried:SP: */
-	theSP = GIV(stackPointer);
+	theSP = GIV(stackPointer) - BytesPerWord;
 	if (((((usqInt)(longAt(GIV(framePointer) + FoxMethod)))) < (startOfMemory())
 		? ((longAt(GIV(framePointer) + FoxMethod)) & MFMethodFlagHasContextFlag) != 0
 		: (byteAt((GIV(framePointer) + FoxIFrameFlags) + 2)) != 0)) {
@@ -41189,7 +41189,7 @@
     sqInt oopRcvr;
     sqInt oopResult;
     usqLong result;
-    int resultIsNegative;
+    sqInt resultIsNegative;
     char *sp;
 
 	oopArg = longAt(GIV(stackPointer) + (0 * BytesPerWord));
@@ -42991,7 +42991,7 @@
     sqInt fmt;
     usqInt instBytes;
     sqInt instFormat;
-    sqInt newFormat;
+    usqInt newFormat;
     sqInt normalizedInstFormat;
     usqInt numBytes;
     usqInt numSlots;
@@ -61362,7 +61362,7 @@
     usqInt prevFree;
     usqInt prevFreeChunk;
     usqInt prevPrevFree;
-    sqInt prevPrevFreeChunk;
+    usqInt prevPrevFreeChunk;
     sqInt slotBytes;
     sqInt slotBytes1;
     usqInt there;
@@ -67174,7 +67174,7 @@
 bridgeFromto(SpurSegmentInfo *aSegment, SpurSegmentInfo *nextSegmentOrNil)
 {
     usqInt bridgeSpan;
-    usqInt clifton;
+    sqInt clifton;
     usqInt segEnd;
 
 	segEnd = ((aSegment->segSize)) + ((aSegment->segStart));
@@ -67418,7 +67418,7 @@
     sqInt limit;
     sqInt newEndOfMemory;
     sqInt next;
-    usqInt node;
+    sqInt node;
     usqInt numSlots;
     usqInt numSlots1;
     SpurSegmentInfo *seg;
@@ -67761,8 +67761,8 @@
 {
     usqLong firstSavedBridgeWord;
     sqInt nWritten;
-    sqInt pier1;
-    sqInt pier2;
+    usqInt pier1;
+    usqInt pier2;
     usqLong secondSavedBridgeWord;
 
 	pier1 = (((segment->segSize)) + ((segment->segStart))) - (2 * BaseHeaderSize);

Modified: branches/Cog/nsspur64src/vm/cointerp.h
===================================================================
--- branches/Cog/nsspur64src/vm/cointerp.h	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/nsspur64src/vm/cointerp.h	2016-05-17 07:02:33 UTC (rev 3721)
@@ -1,5 +1,5 @@
 /* Automatically generated by
-	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
 
 

Modified: branches/Cog/nsspur64src/vm/gcc3x-cointerp.c
===================================================================
--- branches/Cog/nsspur64src/vm/gcc3x-cointerp.c	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/nsspur64src/vm/gcc3x-cointerp.c	2016-05-17 07:02:33 UTC (rev 3721)
@@ -2,11 +2,11 @@
 
 
 /* Automatically generated by
-	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
    from
-	CoInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CoInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
-static char __buildInfo[] = "CoInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34 " __DATE__ ;
+static char __buildInfo[] = "CoInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24 " __DATE__ ;
 char *__interpBuildInfo = __buildInfo;
 
 
@@ -2439,7 +2439,7 @@
 /*560*/	-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1, 0, 0, 0,-1,-1
 	};
 char expensiveAsserts = 0;
-const char *interpreterVersion = "Newspeak Virtual Machine CoInterpreterPrimitives_VMMaker.oscog-eem.1856";
+const char *interpreterVersion = "Newspeak Virtual Machine CoInterpreterPrimitives_VMMaker.oscog-eem.1860";
 sqInt minBackwardJumpCountForCompile = MinBackwardJumpCountForCompile /* 40 */;
 volatile int sendTrace;
 
@@ -17763,7 +17763,7 @@
 static sqInt
 checkForAndFollowForwardedPrimitiveState(void)
 {   DECL_MAYBE_SQ_GLOBAL_STRUCT
-    signed char accessorDepth;
+    sqInt accessorDepth;
     sqInt firstBytecode;
     sqInt found;
     sqInt found1;
@@ -28137,7 +28137,7 @@
 	(GIV(stackPage)->headSP = GIV(stackPointer));
 	assert(pageListIsWellFormed());
 	/* begin ensureFrameIsMarried:SP: */
-	theSP = GIV(stackPointer);
+	theSP = GIV(stackPointer) - BytesPerWord;
 	if (((((usqInt)(longAt(GIV(framePointer) + FoxMethod)))) < (startOfMemory())
 		? ((longAt(GIV(framePointer) + FoxMethod)) & MFMethodFlagHasContextFlag) != 0
 		: (byteAt((GIV(framePointer) + FoxIFrameFlags) + 2)) != 0)) {
@@ -41198,7 +41198,7 @@
     sqInt oopRcvr;
     sqInt oopResult;
     usqLong result;
-    int resultIsNegative;
+    sqInt resultIsNegative;
     char *sp;
 
 	oopArg = longAt(GIV(stackPointer) + (0 * BytesPerWord));
@@ -43000,7 +43000,7 @@
     sqInt fmt;
     usqInt instBytes;
     sqInt instFormat;
-    sqInt newFormat;
+    usqInt newFormat;
     sqInt normalizedInstFormat;
     usqInt numBytes;
     usqInt numSlots;
@@ -61371,7 +61371,7 @@
     usqInt prevFree;
     usqInt prevFreeChunk;
     usqInt prevPrevFree;
-    sqInt prevPrevFreeChunk;
+    usqInt prevPrevFreeChunk;
     sqInt slotBytes;
     sqInt slotBytes1;
     usqInt there;
@@ -67183,7 +67183,7 @@
 bridgeFromto(SpurSegmentInfo *aSegment, SpurSegmentInfo *nextSegmentOrNil)
 {
     usqInt bridgeSpan;
-    usqInt clifton;
+    sqInt clifton;
     usqInt segEnd;
 
 	segEnd = ((aSegment->segSize)) + ((aSegment->segStart));
@@ -67427,7 +67427,7 @@
     sqInt limit;
     sqInt newEndOfMemory;
     sqInt next;
-    usqInt node;
+    sqInt node;
     usqInt numSlots;
     usqInt numSlots1;
     SpurSegmentInfo *seg;
@@ -67770,8 +67770,8 @@
 {
     usqLong firstSavedBridgeWord;
     sqInt nWritten;
-    sqInt pier1;
-    sqInt pier2;
+    usqInt pier1;
+    usqInt pier2;
     usqLong secondSavedBridgeWord;
 
 	pier1 = (((segment->segSize)) + ((segment->segStart))) - (2 * BaseHeaderSize);

Modified: branches/Cog/nsspursrc/vm/cogit.h
===================================================================
--- branches/Cog/nsspursrc/vm/cogit.h	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/nsspursrc/vm/cogit.h	2016-05-17 07:02:33 UTC (rev 3721)
@@ -1,5 +1,5 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGenerator VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
 
 

Modified: branches/Cog/nsspursrc/vm/cogitARMv5.c
===================================================================
--- branches/Cog/nsspursrc/vm/cogitIA32.c	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/nsspursrc/vm/cogitIA32.c	2016-05-17 07:02:33 UTC (rev 3721)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGenerator VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
    from
-	StackToRegisterMappingCogit VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	StackToRegisterMappingCogit VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
-static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34 " __DATE__ ;
+static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -9011,7 +9011,7 @@
 findMapLocationForMcpcinMethod(sqInt targetMcpc, CogMethod *cogMethod)
 {
     sqInt annotation;
-    sqInt map;
+    usqInt map;
     sqInt mapByte;
     usqInt mcpc;
 
@@ -9097,7 +9097,7 @@
     sqInt annotation;
     sqInt map;
     sqInt mapByte;
-    usqInt mcpc;
+    sqInt mcpc;
     sqInt result;
 
 	assert((((cogMethod->cmType)) != CMMethod)
@@ -9669,12 +9669,12 @@
 generateMapAtstart(sqInt addressOrNull, sqInt startAddress)
 {
     unsigned char annotation;
-    sqInt delta;
+    usqInt delta;
     sqInt i;
     AbstractInstruction *instruction;
     sqInt length;
-    sqInt location;
-    sqInt mapEntry;
+    usqInt location;
+    usqInt mapEntry;
     sqInt maxDelta;
     usqInt mcpc;
 
@@ -10943,7 +10943,7 @@
     sqInt annotation;
     sqInt map;
     sqInt mapByte;
-    usqInt mcpc;
+    sqInt mcpc;
     sqInt result;
 
 	mcpc = (0
@@ -11048,7 +11048,7 @@
     sqInt hasYoungObjPtr;
     sqInt map;
     sqInt mapByte;
-    usqInt mcpc;
+    sqInt mcpc;
     sqInt remappedMethod;
     sqInt result;
     sqInt val;
@@ -11164,7 +11164,7 @@
     CogMethod *cogMethod;
     sqInt map;
     sqInt mapByte;
-    usqInt mcpc;
+    sqInt mcpc;
     sqInt result;
 
 	codeModified = 0;
@@ -11242,7 +11242,7 @@
     sqInt hasYoungObjPtr;
     sqInt map;
     sqInt mapByte;
-    usqInt mcpc;
+    sqInt mcpc;
     usqInt pointer;
     sqInt result;
     sqInt val;
@@ -11362,8 +11362,8 @@
     sqInt map1;
     sqInt mapByte;
     sqInt mapByte1;
-    usqInt mcpc;
-    usqInt mcpc1;
+    sqInt mcpc;
+    sqInt mcpc1;
     sqInt result;
     sqInt result1;
     sqInt val;
@@ -11516,7 +11516,7 @@
     sqInt annotation;
     sqInt map;
     sqInt mapByte;
-    usqInt mcpc;
+    sqInt mcpc;
     sqInt result;
     sqInt val;
 
@@ -11856,7 +11856,7 @@
     CogMethod *cogMethod;
     sqInt map;
     sqInt mapByte;
-    usqInt mcpc;
+    sqInt mcpc;
     sqInt result;
 
 	assert((((aCogMethod->cmType)) == CMMethod)
@@ -12430,7 +12430,7 @@
     sqInt annotation;
     sqInt map;
     unsigned char mapByte;
-    usqInt mcpc;
+    sqInt mcpc;
     sqInt value;
 
 	mcpc = (0
@@ -12602,7 +12602,7 @@
     sqLong callDelta;
     sqInt map;
     sqInt mapByte;
-    usqInt mcpc;
+    sqInt mcpc;
     sqLong refDelta;
     sqInt result;
 
@@ -13161,7 +13161,7 @@
     CogMethod *cogMethod;
     sqInt map;
     sqInt mapByte;
-    usqInt mcpc;
+    sqInt mcpc;
     sqInt result;
 
 	if (!(methodZoneBase)) {
@@ -13602,7 +13602,7 @@
     sqInt freedPIC;
     sqInt map;
     sqInt mapByte;
-    usqInt mcpc;
+    sqInt mcpc;
     sqInt result;
 
 	if (!(methodZoneBase)) {
@@ -13677,7 +13677,7 @@
     CogMethod *cogMethod;
     sqInt map;
     sqInt mapByte;
-    usqInt mcpc;
+    sqInt mcpc;
     sqInt mustScanAndUnlink;
     sqInt result;
 
@@ -13774,7 +13774,7 @@
     CogMethod *cogMethod;
     sqInt map;
     sqInt mapByte;
-    usqInt mcpc;
+    sqInt mcpc;
     sqInt result;
 
 	if (!(methodZoneBase)) {
@@ -13841,7 +13841,7 @@
     sqInt freedPIC;
     sqInt map;
     sqInt mapByte;
-    usqInt mcpc;
+    sqInt mcpc;
     sqInt result;
     CogMethod *targetMethod;
 

Modified: branches/Cog/nsspursrc/vm/cogitMIPSEL.c
===================================================================
--- branches/Cog/nsspursrc/vm/cogitMIPSEL.c	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/nsspursrc/vm/cogitMIPSEL.c	2016-05-17 07:02:33 UTC (rev 3721)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGenerator VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
    from
-	StackToRegisterMappingCogit VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	StackToRegisterMappingCogit VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
-static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34 " __DATE__ ;
+static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -2643,7 +2643,7 @@
 blockDispatchTargetsForperformarg(CogMethod *cogMethod, usqInt (*binaryFunction)(sqInt mcpc, sqInt arg), sqInt arg)
 {
     sqInt blockEntry;
-    usqInt end;
+    sqInt end;
     sqInt pc;
     sqInt result;
     usqInt targetpc;
@@ -2692,7 +2692,7 @@
     sqInt isBackwardBranch;
     sqInt isInBlock;
     sqInt latestContinuation;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     usqInt mcpc1;
     sqInt nExts;
@@ -5098,7 +5098,7 @@
     sqInt annotation;
     usqInt map;
     sqInt mapByte;
-    sqInt mcpc;
+    usqInt mcpc;
 
 	mcpc = (0
 		? (((usqInt)cogMethod)) + cbNoSwitchEntryOffset
@@ -5180,7 +5180,7 @@
 followForwardedLiteralsIn(CogMethod *cogMethod)
 {
     sqInt annotation;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     sqInt mcpc;
     sqInt result;
@@ -5778,12 +5778,12 @@
 generateMapAtstart(sqInt addressOrNull, sqInt startAddress)
 {
     unsigned char annotation;
-    usqInt delta;
+    sqInt delta;
     sqInt i;
     AbstractInstruction *instruction;
     sqInt length;
-    usqInt location;
-    usqInt mapEntry;
+    sqInt location;
+    sqInt mapEntry;
     sqInt maxDelta;
     usqInt mcpc;
 
@@ -7011,7 +7011,7 @@
 mapForperformUntilarg(CogMethod *cogMethod, sqInt (*functionSymbol)(sqInt annotation, char *mcpc, sqInt arg), sqInt arg)
 {
     sqInt annotation;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     sqInt mcpc;
     sqInt result;
@@ -7115,7 +7115,7 @@
     sqInt freedPIC;
     sqInt hasYoungObj;
     sqInt hasYoungObjPtr;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     sqInt mcpc;
     sqInt remappedMethod;
@@ -7231,7 +7231,7 @@
 {
     sqInt annotation;
     CogMethod *cogMethod;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     sqInt mcpc;
     sqInt result;
@@ -7309,7 +7309,7 @@
     CogMethod *cogMethod;
     sqInt hasYoungObj;
     sqInt hasYoungObjPtr;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     sqInt mcpc;
     usqInt pointer;
@@ -7427,8 +7427,8 @@
     sqInt annotation;
     sqInt annotation1;
     CogMethod *cogMethod;
-    usqInt map;
-    usqInt map1;
+    sqInt map;
+    sqInt map1;
     sqInt mapByte;
     sqInt mapByte1;
     sqInt mcpc;
@@ -7583,7 +7583,7 @@
 markAndTraceOrFreeCogMethodfirstVisit(CogMethod *cogMethod, sqInt firstVisit)
 {
     sqInt annotation;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     sqInt mcpc;
     sqInt result;
@@ -7923,7 +7923,7 @@
 {
     sqInt annotation;
     CogMethod *cogMethod;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     sqInt mcpc;
     sqInt result;
@@ -8054,7 +8054,7 @@
     sqInt isBackwardBranch;
     sqInt isInBlock;
     sqInt latestContinuation;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     usqInt mcpc;
     sqInt nExts;
@@ -8497,9 +8497,9 @@
 printPCMapPairsFor(CogMethod *cogMethod)
 {
     sqInt annotation;
-    usqInt map;
+    sqInt map;
     unsigned char mapByte;
-    usqInt mcpc;
+    sqInt mcpc;
     sqInt value;
 
 	mcpc = (0
@@ -8669,7 +8669,7 @@
 {
     sqInt annotation;
     sqLong callDelta;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     sqInt mcpc;
     sqLong refDelta;
@@ -9229,7 +9229,7 @@
 {
     sqInt annotation;
     CogMethod *cogMethod;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     sqInt mcpc;
     sqInt result;
@@ -9670,7 +9670,7 @@
     sqInt annotation;
     CogMethod *cogMethod;
     sqInt freedPIC;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     sqInt mcpc;
     sqInt result;
@@ -9745,7 +9745,7 @@
 {
     sqInt annotation;
     CogMethod *cogMethod;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     sqInt mcpc;
     sqInt mustScanAndUnlink;
@@ -9842,7 +9842,7 @@
 {
     sqInt annotation;
     CogMethod *cogMethod;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     sqInt mcpc;
     sqInt result;
@@ -9909,7 +9909,7 @@
     sqInt annotation;
     CogMethod *cogMethod;
     sqInt freedPIC;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     sqInt mcpc;
     sqInt result;
@@ -22255,7 +22255,7 @@
     sqInt isBackwardBranch;
     sqInt isInBlock;
     sqInt latestContinuation;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     usqInt mcpc;
     sqInt nExts;

Modified: branches/Cog/nsspursrc/vm/cointerp.c
===================================================================
--- branches/Cog/nsspursrc/vm/cointerp.c	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/nsspursrc/vm/cointerp.c	2016-05-17 07:02:33 UTC (rev 3721)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
    from
-	CoInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CoInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
-static char __buildInfo[] = "CoInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34 " __DATE__ ;
+static char __buildInfo[] = "CoInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24 " __DATE__ ;
 char *__interpBuildInfo = __buildInfo;
 
 
@@ -2412,7 +2412,7 @@
 /*560*/	-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1, 0, 0, 0,-1,-1
 	};
 char expensiveAsserts = 0;
-const char *interpreterVersion = "Newspeak Virtual Machine CoInterpreterPrimitives_VMMaker.oscog-eem.1856";
+const char *interpreterVersion = "Newspeak Virtual Machine CoInterpreterPrimitives_VMMaker.oscog-eem.1860";
 sqInt minBackwardJumpCountForCompile = MinBackwardJumpCountForCompile /* 40 */;
 volatile int sendTrace;
 
@@ -27836,7 +27836,7 @@
 	(GIV(stackPage)->headSP = GIV(stackPointer));
 	assert(pageListIsWellFormed());
 	/* begin ensureFrameIsMarried:SP: */
-	theSP = GIV(stackPointer);
+	theSP = GIV(stackPointer) - BytesPerWord;
 	if (((((usqInt)(longAt(GIV(framePointer) + FoxMethod)))) < (startOfMemory())
 		? ((longAt(GIV(framePointer) + FoxMethod)) & MFMethodFlagHasContextFlag) != 0
 		: (byteAt((GIV(framePointer) + FoxIFrameFlags) + 2)) != 0)) {
@@ -30466,7 +30466,7 @@
     sqInt oopRcvr;
     sqInt oopResult;
     usqLong result;
-    sqInt shift;
+    int shift;
     char *sp;
 
 	/* begin stackIntegerValue: */
@@ -30481,7 +30481,7 @@
 		if (!GIV(primFailCode)) {
 			GIV(primFailCode) = 1;
 		}
-		shift = 0;
+		shift = ((sqInt) 0);
 		goto l1;
 	}
 l1:	/* end stackIntegerValue: */;
@@ -40373,7 +40373,7 @@
     sqInt oopRcvr;
     sqInt oopResult;
     usqLong result;
-    int resultIsNegative;
+    sqInt resultIsNegative;
     char *sp;
 
 	oopArg = longAt(GIV(stackPointer) + (0 * BytesPerWord));
@@ -40534,7 +40534,7 @@
 static void
 primitiveTimesTwoPower(void)
 {   DECL_MAYBE_SQ_GLOBAL_STRUCT
-    sqInt arg;
+    int arg;
     sqInt isFloat;
     sqInt oop;
     double rcvr;
@@ -46206,7 +46206,7 @@
     sqInt effectsFlags1;
     sqInt errCode;
     sqInt fieldOffset;
-    usqInt fieldOffset1;
+    sqInt fieldOffset1;
     sqInt fmt;
     sqInt hash;
     sqInt header;
@@ -60296,7 +60296,7 @@
     usqInt prevFree;
     usqInt prevFreeChunk;
     usqInt prevPrevFree;
-    sqInt prevPrevFreeChunk;
+    usqInt prevPrevFreeChunk;
     sqInt slotBytes;
     sqInt slotBytes1;
     usqInt there;
@@ -66092,7 +66092,7 @@
 bridgeFromto(SpurSegmentInfo *aSegment, SpurSegmentInfo *nextSegmentOrNil)
 {
     usqInt bridgeSpan;
-    sqInt clifton;
+    usqInt clifton;
     usqInt segEnd;
 
 	segEnd = ((aSegment->segSize)) + ((aSegment->segStart));
@@ -66273,7 +66273,7 @@
 static void
 postSnapshot(void)
 {   DECL_MAYBE_SQ_GLOBAL_STRUCT
-    sqInt address;
+    usqInt address;
     sqInt bytes;
     usqInt freeChunk;
     sqInt i;
@@ -66679,8 +66679,8 @@
 {
     usqLong firstSavedBridgeWord;
     sqInt nWritten;
-    sqInt pier1;
-    sqInt pier2;
+    usqInt pier1;
+    usqInt pier2;
     usqLong secondSavedBridgeWord;
 
 	pier1 = (((segment->segSize)) + ((segment->segStart))) - (2 * BaseHeaderSize);

Modified: branches/Cog/nsspursrc/vm/cointerp.h
===================================================================
--- branches/Cog/nsspursrc/vm/cointerp.h	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/nsspursrc/vm/cointerp.h	2016-05-17 07:02:33 UTC (rev 3721)
@@ -1,5 +1,5 @@
 /* Automatically generated by
-	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
 
 

Modified: branches/Cog/nsspursrc/vm/gcc3x-cointerp.c
===================================================================
--- branches/Cog/nsspursrc/vm/gcc3x-cointerp.c	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/nsspursrc/vm/gcc3x-cointerp.c	2016-05-17 07:02:33 UTC (rev 3721)
@@ -2,11 +2,11 @@
 
 
 /* Automatically generated by
-	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
    from
-	CoInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CoInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
-static char __buildInfo[] = "CoInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34 " __DATE__ ;
+static char __buildInfo[] = "CoInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24 " __DATE__ ;
 char *__interpBuildInfo = __buildInfo;
 
 
@@ -2415,7 +2415,7 @@
 /*560*/	-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1, 0, 0, 0,-1,-1
 	};
 char expensiveAsserts = 0;
-const char *interpreterVersion = "Newspeak Virtual Machine CoInterpreterPrimitives_VMMaker.oscog-eem.1856";
+const char *interpreterVersion = "Newspeak Virtual Machine CoInterpreterPrimitives_VMMaker.oscog-eem.1860";
 sqInt minBackwardJumpCountForCompile = MinBackwardJumpCountForCompile /* 40 */;
 volatile int sendTrace;
 
@@ -27845,7 +27845,7 @@
 	(GIV(stackPage)->headSP = GIV(stackPointer));
 	assert(pageListIsWellFormed());
 	/* begin ensureFrameIsMarried:SP: */
-	theSP = GIV(stackPointer);
+	theSP = GIV(stackPointer) - BytesPerWord;
 	if (((((usqInt)(longAt(GIV(framePointer) + FoxMethod)))) < (startOfMemory())
 		? ((longAt(GIV(framePointer) + FoxMethod)) & MFMethodFlagHasContextFlag) != 0
 		: (byteAt((GIV(framePointer) + FoxIFrameFlags) + 2)) != 0)) {
@@ -30475,7 +30475,7 @@
     sqInt oopRcvr;
     sqInt oopResult;
     usqLong result;
-    sqInt shift;
+    int shift;
     char *sp;
 
 	/* begin stackIntegerValue: */
@@ -30490,7 +30490,7 @@
 		if (!GIV(primFailCode)) {
 			GIV(primFailCode) = 1;
 		}
-		shift = 0;
+		shift = ((sqInt) 0);
 		goto l1;
 	}
 l1:	/* end stackIntegerValue: */;
@@ -40382,7 +40382,7 @@
     sqInt oopRcvr;
     sqInt oopResult;
     usqLong result;
-    int resultIsNegative;
+    sqInt resultIsNegative;
     char *sp;
 
 	oopArg = longAt(GIV(stackPointer) + (0 * BytesPerWord));
@@ -40543,7 +40543,7 @@
 static void
 primitiveTimesTwoPower(void)
 {   DECL_MAYBE_SQ_GLOBAL_STRUCT
-    sqInt arg;
+    int arg;
     sqInt isFloat;
     sqInt oop;
     double rcvr;
@@ -46215,7 +46215,7 @@
     sqInt effectsFlags1;
     sqInt errCode;
     sqInt fieldOffset;
-    usqInt fieldOffset1;
+    sqInt fieldOffset1;
     sqInt fmt;
     sqInt hash;
     sqInt header;
@@ -60305,7 +60305,7 @@
     usqInt prevFree;
     usqInt prevFreeChunk;
     usqInt prevPrevFree;
-    sqInt prevPrevFreeChunk;
+    usqInt prevPrevFreeChunk;
     sqInt slotBytes;
     sqInt slotBytes1;
     usqInt there;
@@ -66101,7 +66101,7 @@
 bridgeFromto(SpurSegmentInfo *aSegment, SpurSegmentInfo *nextSegmentOrNil)
 {
     usqInt bridgeSpan;
-    sqInt clifton;
+    usqInt clifton;
     usqInt segEnd;
 
 	segEnd = ((aSegment->segSize)) + ((aSegment->segStart));
@@ -66282,7 +66282,7 @@
 static void
 postSnapshot(void)
 {   DECL_MAYBE_SQ_GLOBAL_STRUCT
-    sqInt address;
+    usqInt address;
     sqInt bytes;
     usqInt freeChunk;
     sqInt i;
@@ -66688,8 +66688,8 @@
 {
     usqLong firstSavedBridgeWord;
     sqInt nWritten;
-    sqInt pier1;
-    sqInt pier2;
+    usqInt pier1;
+    usqInt pier2;
     usqLong secondSavedBridgeWord;
 
 	pier1 = (((segment->segSize)) + ((segment->segStart))) - (2 * BaseHeaderSize);

Modified: branches/Cog/nsspurstack64src/vm/gcc3x-interp.c
===================================================================
--- branches/Cog/nsspurstack64src/vm/gcc3x-interp.c	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/nsspurstack64src/vm/gcc3x-interp.c	2016-05-17 07:02:33 UTC (rev 3721)
@@ -2,11 +2,11 @@
 
 
 /* Automatically generated by
-	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
    from
-	StackInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	StackInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
-static char __buildInfo[] = "StackInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34 " __DATE__ ;
+static char __buildInfo[] = "StackInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24 " __DATE__ ;
 char *__interpBuildInfo = __buildInfo;
 
 
@@ -2178,7 +2178,7 @@
 	/* 575 */ (void (*)(void))0,
  0 };
 char expensiveAsserts = 0;
-const char *interpreterVersion = "Newspeak Virtual Machine StackInterpreterPrimitives_VMMaker.oscog-eem.1856";
+const char *interpreterVersion = "Newspeak Virtual Machine StackInterpreterPrimitives_VMMaker.oscog-eem.1860";
 volatile int sendTrace;
 sqInt suppressHeartbeatFlag;
 

Modified: branches/Cog/nsspurstack64src/vm/interp.c
===================================================================
--- branches/Cog/nsspurstack64src/vm/interp.c	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/nsspurstack64src/vm/interp.c	2016-05-17 07:02:33 UTC (rev 3721)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
    from
-	StackInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	StackInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
-static char __buildInfo[] = "StackInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34 " __DATE__ ;
+static char __buildInfo[] = "StackInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24 " __DATE__ ;
 char *__interpBuildInfo = __buildInfo;
 
 
@@ -2175,7 +2175,7 @@
 	/* 575 */ (void (*)(void))0,
  0 };
 char expensiveAsserts = 0;
-const char *interpreterVersion = "Newspeak Virtual Machine StackInterpreterPrimitives_VMMaker.oscog-eem.1856";
+const char *interpreterVersion = "Newspeak Virtual Machine StackInterpreterPrimitives_VMMaker.oscog-eem.1860";
 volatile int sendTrace;
 sqInt suppressHeartbeatFlag;
 

Modified: branches/Cog/nsspurstacksrc/vm/gcc3x-interp.c
===================================================================
--- branches/Cog/nsspurstacksrc/vm/gcc3x-interp.c	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/nsspurstacksrc/vm/gcc3x-interp.c	2016-05-17 07:02:33 UTC (rev 3721)
@@ -2,11 +2,11 @@
 
 
 /* Automatically generated by
-	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
    from
-	StackInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	StackInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
-static char __buildInfo[] = "StackInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34 " __DATE__ ;
+static char __buildInfo[] = "StackInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24 " __DATE__ ;
 char *__interpBuildInfo = __buildInfo;
 
 
@@ -2155,7 +2155,7 @@
 	/* 575 */ (void (*)(void))0,
  0 };
 char expensiveAsserts = 0;
-const char *interpreterVersion = "Newspeak Virtual Machine StackInterpreterPrimitives_VMMaker.oscog-eem.1856";
+const char *interpreterVersion = "Newspeak Virtual Machine StackInterpreterPrimitives_VMMaker.oscog-eem.1860";
 volatile int sendTrace;
 sqInt suppressHeartbeatFlag;
 

Modified: branches/Cog/nsspurstacksrc/vm/interp.c
===================================================================
--- branches/Cog/nsspurstacksrc/vm/interp.c	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/nsspurstacksrc/vm/interp.c	2016-05-17 07:02:33 UTC (rev 3721)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
    from
-	StackInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	StackInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
-static char __buildInfo[] = "StackInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34 " __DATE__ ;
+static char __buildInfo[] = "StackInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24 " __DATE__ ;
 char *__interpBuildInfo = __buildInfo;
 
 
@@ -2152,7 +2152,7 @@
 	/* 575 */ (void (*)(void))0,
  0 };
 char expensiveAsserts = 0;
-const char *interpreterVersion = "Newspeak Virtual Machine StackInterpreterPrimitives_VMMaker.oscog-eem.1856";
+const char *interpreterVersion = "Newspeak Virtual Machine StackInterpreterPrimitives_VMMaker.oscog-eem.1860";
 volatile int sendTrace;
 sqInt suppressHeartbeatFlag;
 


Property changes on: branches/Cog/platforms/Cross/vm/sqSCCSVersion.h
___________________________________________________________________
Modified: checkindate
   - Mon May  9 19:17:20 PDT 2016
   + Mon May 16 23:58:26 PDT 2016

Modified: branches/Cog/spur64src/vm/cogit.h
===================================================================
--- branches/Cog/spur64src/vm/cogit.h	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/spur64src/vm/cogit.h	2016-05-17 07:02:33 UTC (rev 3721)
@@ -1,5 +1,5 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGenerator VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
 
 

Modified: branches/Cog/spur64src/vm/cogitX64.c
===================================================================
--- branches/Cog/spur64src/vm/cogitX64.c	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/spur64src/vm/cogitX64.c	2016-05-17 07:02:33 UTC (rev 3721)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGenerator VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
    from
-	StackToRegisterMappingCogit VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	StackToRegisterMappingCogit VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
-static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34 " __DATE__ ;
+static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -584,7 +584,7 @@
 static AbstractInstruction * NoDbgRegParms gMoveCwR(sqInt wordConstant, sqInt reg);
 static AbstractInstruction * NoDbgRegParms gMoveRMwr(sqInt sourceReg, sqInt offset, sqInt baseReg);
 static AbstractInstruction * NoDbgRegParms gMoveRR(sqInt reg1, sqInt reg2);
-static usqInt NoDbgRegParms mapEndFor(CogMethod *cogMethod);
+static sqInt NoDbgRegParms mapEndFor(CogMethod *cogMethod);
 static sqInt NoDbgRegParms mapForperformUntilarg(CogMethod *cogMethod, sqInt (*functionSymbol)(sqInt annotation, char *mcpc, sqInt arg), sqInt arg);
 static sqInt NoDbgRegParms mapObjectReferencesInClosedPIC(CogMethod *cPIC);
 static void mapObjectReferencesInGeneratedRuntime(void);
@@ -2430,7 +2430,7 @@
 blockDispatchTargetsForperformarg(CogMethod *cogMethod, usqInt (*binaryFunction)(sqInt mcpc, sqInt arg), sqInt arg)
 {
     sqInt blockEntry;
-    usqInt end;
+    sqInt end;
     sqInt pc;
     sqInt result;
     usqInt targetpc;
@@ -2479,7 +2479,7 @@
     sqInt isBackwardBranch;
     sqInt isInBlock;
     sqInt latestContinuation;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     usqInt mcpc1;
     sqInt nExts;
@@ -3255,7 +3255,7 @@
 closedPICRefersToUnmarkedObject(CogMethod *cPIC)
 {
     sqInt i;
-    usqInt object;
+    sqInt object;
     sqInt pc;
 
 	if (!((isImmediate((cPIC->selector)))
@@ -4779,7 +4779,7 @@
 findMapLocationForMcpcinMethod(sqInt targetMcpc, CogMethod *cogMethod)
 {
     sqInt annotation;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     sqInt mcpc;
 
@@ -6512,10 +6512,10 @@
 /*	Answer the address of the null byte at the end of the method map. */
 
 	/* Cogit>>#mapEndFor: */
-static usqInt NoDbgRegParms
+static sqInt NoDbgRegParms
 mapEndFor(CogMethod *cogMethod)
 {
-    usqInt end;
+    sqInt end;
 
 	end = ((((usqInt)cogMethod)) + ((cogMethod->blockSize))) - 1;
 	while ((byteAt(end)) != MapEnd) {
@@ -7464,7 +7464,7 @@
     sqInt isBackwardBranch;
     sqInt isInBlock;
     sqInt latestContinuation;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     usqInt mcpc;
     sqInt nExts;
@@ -7907,9 +7907,9 @@
 printPCMapPairsFor(CogMethod *cogMethod)
 {
     sqInt annotation;
-    usqInt map;
+    sqInt map;
     unsigned char mapByte;
-    sqInt mcpc;
+    usqInt mcpc;
     sqInt value;
 
 	mcpc = (0
@@ -21009,7 +21009,7 @@
     sqInt isBackwardBranch;
     sqInt isInBlock;
     sqInt latestContinuation;
-    usqInt map;
+    sqInt map;
     sqInt mapByte;
     usqInt mcpc;
     sqInt nExts;

Modified: branches/Cog/spur64src/vm/cointerp.c
===================================================================
--- branches/Cog/spur64src/vm/cointerp.c	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/spur64src/vm/cointerp.c	2016-05-17 07:02:33 UTC (rev 3721)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGeneratorGlobalStructure VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
    from
-	CoInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CoInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
-static char __buildInfo[] = "CoInterpreter VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34 " __DATE__ ;
+static char __buildInfo[] = "CoInterpreter VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24 " __DATE__ ;
 char *__interpBuildInfo = __buildInfo;
 
 
@@ -2399,7 +2399,7 @@

@@ Diff output truncated at 50000 characters. @@


More information about the Vm-dev mailing list
--- branches/Cog/nsspursrc/vm/cogitARMv5.c	2016-05-16 21:09:31 UTC (rev 3720)
+++ branches/Cog/nsspursrc/vm/cogitARMv5.c	2016-05-17 07:02:33 UTC (rev 3721)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	CCodeGenerator VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
    from
-	StackToRegisterMappingCogit VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34
+	StackToRegisterMappingCogit VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24
  */
-static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1856 uuid: ddc1d13f-a8de-4cb1-af85-65ca64ffbe34 " __DATE__ ;
+static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1860 uuid: 4d58d995-ee0c-4330-9190-adfa038e8f24 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -703,7 +703,7 @@
 static AbstractInstruction * NoDbgRegParms gMoveMwrR(sqInt offset, sqInt baseReg, sqInt destReg);
 static AbstractInstruction * NoDbgRegParms gMoveRMwr(sqInt sourceReg, sqInt offset, sqInt baseReg);
 static AbstractInstruction * NoDbgRegParms gMoveRR(sqInt reg1, sqInt reg2);
-static usqInt NoDbgRegParms mapEndFor(CogMethod *cogMethod);
+static sqInt NoDbgRegParms mapEndFor(CogMethod *cogMethod);
 static sqInt NoDbgRegParms mapForperformUntilarg(CogMethod *cogMethod, sqInt (*functionSymbol)(sqInt annotation, char *mcpc, sqInt arg), sqInt arg);
 static sqInt NoDbgRegParms mapObjectReferencesInClosedPIC(CogMethod *cPIC);
 static void mapObjectReferencesInGeneratedRuntime(void);
@@ -2253,7 +2253,7 @@
 
 
 /*	Remember the ROR is doubled by the cpu so use 30>>1 etc
-	ADDS destReg, srcREg, #immediate ROR #rot */
+	ADDS destReg, srcReg, #immediate ROR #rot - ARM_ARM v7 DDI10406 p. A8-23 */
 
 	/* CogARMCompiler>>#adds:rn:imm:ror: */
 static sqInt NoDbgRegParms
@@ -2264,7 +2264,7 @@
 
 
 /*	Remember the ROR is doubled by the cpu so use 30>>1 etc.
-	ADD destReg, srcReg, #immediate ROR #rot */
+	ADD destReg, srcReg, #immediate ROR #rot - ARM_ARM v7 DDI10406 p. A8-23 */
 
 	/* CogARMCompiler>>#add:rn:imm:ror: */
 static sqInt NoDbgRegParms
@@ -2275,7 +2275,7 @@
 
 
 /*	return an ADD destReg, srcReg, addReg instruction
-	ADD destReg, srcReg, addReg */
+	ADD destReg, srcReg, addReg - ARM_ARM v7 DDI10406 p. A8-24 */
 
 	/* CogARMCompiler>>#add:rn:rm: */
 static sqInt NoDbgRegParms
@@ -2306,7 +2306,7 @@
 
 
 /*	Remember the ROR is doubled by the cpu so use 30>>1 etc
-	ANDS destReg, srcReg, #immediate ROR #rot */
+	ANDS destReg, srcReg, #immediate ROR #rot - ARM_ARM v7 DDI10406 p. A8-34 */
 
 	/* CogARMCompiler>>#ands:rn:imm:ror: */
 static sqInt NoDbgRegParms
@@ -2317,7 +2317,7 @@
 
 
 /*	Remember the ROR is doubled by the cpu so use 30>>1 etc
-	AND destReg, srcReg, #immediate ROR #rot */
+	AND destReg, srcReg, #immediate ROR #rot - ARM_ARM v7 DDI10406 p. A8-34 */
 
 	/* CogARMCompiler>>#and:rn:imm:ror: */
 static sqInt NoDbgRegParms
@@ -2361,7 +2361,9 @@
 
 
 /*	Remember the ROR is doubled by the cpu so use 30>>1 etc
-	BICS destReg, srcReg, #immediate ROR #rot */
+	BICS destReg, srcReg, #immediate ROR #rot - ARM_ARM v7 DDI10406 pp.
+	A8-50-1 
+ */
 
 	/* CogARMCompiler>>#bics:rn:imm:ror: */
 static sqInt NoDbgRegParms
@@ -2373,7 +2375,7 @@
 
 /*	return a BL offset instruction; offset is signed 24bits of WORD offset, so
 	+_32Mbyte range. Return address is in LR
-	BL offset
+	BL offset - ARM_ARM v7 DDI10406 pp. A8-58-9
  */
 
 	/* CogARMCompiler>>#bl: */
@@ -2386,7 +2388,7 @@
 
 /*	return a B offset instruction; offset is signed 24bits of WORD offset, so
 	+_32Mbyte range
-	B offset
+	B offset - ARM_ARM v7 DDI10406 pp. A8-44-5
  */
 
 	/* CogARMCompiler>>#b: */
@@ -2793,7 +2795,7 @@
 {
     sqInt aWord;
     sqInt i;
-    sqInt instr;
+    usqInt instr;
     unsigned char savedCond;
 
 	assert(((self_in_concretizeConditionalInstruction->conditionOrNil)) != null);
@@ -5779,9 +5781,10 @@
 }
 
 
 /*	FMSR or VMSR instruction to move a value from an ARM reg to an fpu double
 	register ready for conversion
-	ARM_ARM v5 DDI 01001.pdf pp. C4-68
+	FMSR regB, regA - ARM_ARM v5 DDI 01001.pdf pp. C4-68
+	VMOV regB, regA - ARM_ARM v7 DDi10406 pp. A8-462-3
  */
 /*	the dest reg bits are spread out a little */
 
@@ -5797,7 +5800,8 @@
 
 
 /*	FSITOD or VCVT instruction to move convert an integer value to an fpu
-	double ARM_ARM v5 DDI 01001.pdf pp. C4-95
+	double FSITOD regB, regA - ARM_ARM v5 DDI 01001.pdf pp. C4-95
+	VCVTW. regB, regA - ARM_ARM v7 DDI10406.pdf pp. A8-576-8
  */
 /*	the src reg bits are spread out a little */
 
@@ -5962,7 +5966,8 @@
 }
 
 
-/*	Use SMULL to produce a 64-bit result, explicitly in RISCTempReg,regDest.
+/*	Use SMULL to produce a 64-bit result, explicitly in RISCTempReg,regDest. -
+	ARM_ARM v7 DDI10406 pp. A8-354-5
 	By comparing RISCTempReg with regDest ASR 31(which effectively makes it 0
 	or -1) we know that the result being EQ means the hi reg and the top bit
 	of the lo reg are the same - ie no overflow. The condition code can then
@@ -6416,11 +6421,10 @@
 }
 
 
-/*	LDRB destReg, [baseReg, 'u' immediate12bitValue] u=0 -> subtract imm; =1
-	-> add imm 
+/*	LDRB destReg, [baseReg, 'u' immediate12bitValue] u=0 -> - ARM_ARM v7
+	DDI10406 pp. A8-128-9
 	Note that this is a very low level interface that does not check the sign
-	of the immediate, nor validity. See for example #concretizeMoveMbrR
- */
+	of the immediate, nor validity. See for example #concretizeMoveMbrR */
 
 	/* CogARMCompiler>>#ldrb:rn:plus:imm: */
 static sqInt NoDbgRegParms
@@ -6430,7 +6434,7 @@
 }
 
 
-/*	LDR destReg, [baseReg, + offsetReg] 
+/*	LDRB destReg, [baseReg, + offsetReg] - ARM_ARM v7 DDI10406 pp. A8-132-3
 	The contents of offsetReg are assumed to be correctly signed */
 
 	/* CogARMCompiler>>#ldrb:rn:rm: */
@@ -6442,7 +6446,7 @@
 
 
 /*	LDRH destReg, [baseReg, 'u' immediate8bitValue] u=0 -> subtract imm; =1 ->
-	add imm */
+	add imm - ARM_ARM v7 DDI10406 pp. A8-152-3 */
 
 	/* CogARMCompiler>>#ldrh:rn:plus:imm: */
 static sqInt NoDbgRegParms
@@ -6452,7 +6456,7 @@
 }
 
 
-/*	LDRH destReg, [baseReg, +offsetReg]
+/*	LDRH destReg, [baseReg, +offsetReg] - ARM_ARM v7 DDI10406 pp. A8-156-7
 	The contents of offsetReg are assumed to be correctly signed */
 
 	/* CogARMCompiler>>#ldrh:rn:rm: */
@@ -6463,7 +6467,9 @@
 }
 
 
-/*	LDR destReg, [baseReg, +immediate12bitValue] */
+/*	LDR destReg, [baseReg, +immediate12bitValue] - ARM_ARM v7 DDI10406 pp.
+	A8-120-1 
+ */
 
 	/* CogARMCompiler>>#ldr:rn:plusImm: */
 static sqInt NoDbgRegParms
@@ -6474,7 +6480,7 @@
 
 
 /*	LDR destReg, [baseReg, immediate12bitValue] u=0 -> subtract imm; =1 -> add
-	imm  */
+	imm - ARM_ARM v7 DDI10406 pp. A8-120-1 */
 
 	/* CogARMCompiler>>#ldr:rn:plus:imm: */
 static sqInt NoDbgRegParms
@@ -6484,7 +6490,7 @@
 }
 
 
-/*	LDR destReg, [baseReg, + offsetReg]
+/*	LDR destReg, [baseReg, + offsetReg] - ARM_ARM v7 DDI10406 pp. A8-124-5
 	The contents of offsetReg are assumed to be correctly signed */
 
 	/* CogARMCompiler>>#ldr:rn:rm: */
@@ -6714,7 +6720,7 @@
 }
 
 
 /*	MOVS destReg, srcReg */
 
 	/* CogARMCompiler>>#movs:rn: */
 static sqInt NoDbgRegParms
@@ -6725,7 +6731,9 @@
 
 
 /*	Remember the ROR is doubled by the cpu so use 30>>1 etc.
-	MOV destReg, #immediate8BitValue ROR rot */
+	MOV destReg, #immediate8BitValue ROR rot - ARM_ARM v7 DDI10406 pp.
+	A8-194-5 
+ */
 
 	/* CogARMCompiler>>#mov:imm:ror: */
 static sqInt NoDbgRegParms
@@ -6735,7 +6743,7 @@
 }
 
 
 /*	MOV destReg, srcReg */
 
 	/* CogARMCompiler>>#mov:rn: */
 static sqInt NoDbgRegParms
@@ -6761,7 +6769,9 @@
 
 
 /*	Remember the ROR is doubled by the cpu so use 30>>1 etc.
-	MVN destReg, #immediate8BitValue ROR rot */
+	MVN destReg, #immediate8BitValue ROR rot - ARM_ARM v7 DDI10406 pp.
+	A8-214-5 
+ */
 
 	/* CogARMCompiler>>#mvn:imm:ror: */
 static sqInt NoDbgRegParms
@@ -6779,7 +6789,9 @@
 
 
 /*	Remember the ROR is doubled by the cpu so use 30>>1 etc.
-	ORR destReg, #immediate8BitValue ROR rot */
+	ORR destReg, #immediate8BitValue ROR rot - ARM_ARM v7 DDI10406 pp.
+	A8-228-9 
+ */
 
 	/* CogARMCompiler>>#orr:imm:ror: */
 static sqInt NoDbgRegParms
@@ -6805,7 +6817,7 @@
 
 
 /*	pop word off TOS
-	LDR srcReg, [sp] #4 */
+	LDR srcReg, [sp] #4 - ARM_ARM v7 DDI10406 pp. A8-120-1 */
 
 	/* CogARMCompiler>>#popR: */
 static sqInt NoDbgRegParms
@@ -6823,7 +6835,7 @@
 
 
 /*	push word to TOS 
-	STR srcReg, [sp, #-4]! */
+	STR srcReg, [sp, #-4]! - ARM_ARM v7 DDI10406 pp. A8-382-3 */
 
 	/* CogARMCompiler>>#pushR: */
 static sqInt NoDbgRegParms
@@ -7030,7 +7042,7 @@
 
 
 /*	STRB destReg, [baseReg, 'u' immediate12bitValue] u=0 -> subtract imm; =1
-	-> add imm */
+	-> add imm - ARM_ARM v7 DDI10406 pp. A8-388-9 */
 
 	/* CogARMCompiler>>#strb:rn:plus:imm: */
 static sqInt NoDbgRegParms
@@ -7040,7 +7052,7 @@
 }
 
 
-/*	STRB srcReg, [baseReg, + offsetReg] 
+/*	STRB srcReg, [baseReg, + offsetReg] - ARM_ARM v7 DDI10406 pp. A8-390-1
 	The contents of offsetReg are assumed to be correctly signed */
 
 	/* CogARMCompiler>>#strb:rn:rm: */
@@ -7052,7 +7064,7 @@
 
 
 /*	STRH destReg, [baseReg, 'u' immediate8bitValue] u=0 -> subtract imm; =1 ->
-	add imm */
+	add imm - ARM_ARM v7 DDI10406 pp. A8-408-9 */
 
 	/* CogARMCompiler>>#strh:rn:plus:imm: */
 static sqInt NoDbgRegParms
@@ -7062,7 +7074,7 @@
 }
 
 
-/*	STRH srcReg, [baseReg, +offsetReg] */
+/*	STRH srcReg, [baseReg, +offsetReg] - ARM_ARM v7 DDI10406 pp. A8-410-1 */
 
 	/* CogARMCompiler>>#strh:rn:rm: */
 static sqInt NoDbgRegParms
@@ -7072,7 +7084,9 @@
 }
 
 
-/*	STR srcReg, [baseReg, +immediate12bitValue] */
+/*	STR srcReg, [baseReg, +immediate12bitValue] - ARM_ARM v7 DDI10406 pp.
+	A8-382-3 
+ */
 
 	/* CogARMCompiler>>#str:rn:plusImm: */
 static sqInt NoDbgRegParms
@@ -7083,7 +7097,7 @@
 
 
 /*	STR destReg, [baseReg, 'u' immediate12bitValue] u=0 -> subtract imm; =1 ->
-	add imm */
+	add imm - ARM_ARM v7 DDI10406 pp. A8-382-3 */
 
 	/* CogARMCompiler>>#str:rn:plus:imm: */
 static sqInt NoDbgRegParms
@@ -7093,7 +7107,7 @@
 }
 
 
-/*	STR srcReg, [baseReg, + offsetReg] 
+/*	STR srcReg, [baseReg, + offsetReg] - ARM_ARM v7 DDI10406 pp. A8-384-5
 	The contents of offsetReg are assumed to be correctly signed */
 
 	/* CogARMCompiler>>#str:rn:rm: */
@@ -7105,7 +7119,9 @@
 
 
 /*	Remember the ROR is doubled by the cpu so use 30>>1 etc
-	SUBS destReg, srcReg, #immediate ROR rot */
+	SUBS destReg, srcReg, #immediate ROR rot - ARM_ARM v7 DDI10406 pp.
+	A8-418-9 
+ */
 
 	/* CogARMCompiler>>#subs:rn:imm:ror: */
 static sqInt NoDbgRegParms
@@ -7116,7 +7132,7 @@
 
 
 /*	Remember the ROR is doubled by the cpu so use 30>>1 etc
-	SUB destReg, srcReg, #immediate ROR rot */
+	SUB destReg, srcReg, #immediate ROR rot - ARM_ARM v7 DDI10406 pp. A8-418-9 */
 
 	/* CogARMCompiler>>#sub:rn:imm:ror: */
 static sqInt NoDbgRegParms
@@ -7128,7 +7144,7 @@
 
 /*	Remember the ROR is doubled by the cpu so use 30>>1 etc */
 /*	also note that TST has no destReg
-	TST srcReg, #immediate ROR rot */
+	TST srcReg, #immediate ROR rot - ARM_ARM v7 DDI10406 pp. A8-452-3 */
 
 	/* CogARMCompiler>>#tst:rn:imm:ror: */
 static sqInt NoDbgRegParms
@@ -11911,10 +11927,10 @@
 /*	Answer the address of the null byte at the end of the method map. */
 
 	/* Cogit>>#mapEndFor: */
-static usqInt NoDbgRegParms
+static sqInt NoDbgRegParms
 mapEndFor(CogMethod *cogMethod)
 {
-    usqInt end;
+    sqInt end;
 
 	end = ((((usqInt)cogMethod)) + ((cogMethod->blockSize))) - 1;
 	while ((byteAt(end)) != MapEnd) {
@@ -5779,9 +5781,10 @@
 
 
-/*	FMSR or VMSR instruction to move a value from an ARM reg to an fpu double
+/*	FMSR or VMOV instruction to move a value from an ARM reg to an fpu double
 	register ready for conversion
@@ -6714,7 +6720,7 @@
 
 
-/*	MOVS destReg, srcReg */
+/*	MOVS destReg, srcReg - ARM_ARM v7 DDI10406 pp. A8-196-7 */
 
 	/* CogARMCompiler>>#movs:rn: */
@@ -6735,7 +6743,7 @@
 
 
-/*	MOV destReg, srcReg */
+/*	MOV destReg, srcReg - ARM_ARM v7 DDI10406 pp. A8-196-7 */
 
 	/* CogARMCompiler>>#mov:rn: */

Modified: branches/Cog/nsspursrc/vm/cogitIA32.c
===================================================================